#
# spec file for package libgxps
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgxps
Version:        0.2.2
Release:        12.3
Summary:        Library for rendering XPS documents
License:        LGPL-2.1+
Group:          System/Libraries
Url:            https://live.gnome.org/libgxps
Source0:        http://download.gnome.org/sources/libgxps/0.2/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM libgxps-libpng16.patch pgajdos@suse.com -- Also build against libpng16, patch from upstream git.
Patch0:         libgxps-libpng16.patch
BuildRequires:  gobject-introspection-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
# Only needed because we don't (and won't) support building xz tarballs by default... See bnc#697467
BuildRequires:  xz
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(cairo-pdf)
BuildRequires:  pkgconfig(cairo-ps)
BuildRequires:  pkgconfig(cairo-svg)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gio-2.0) >= 2.24
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(gobject-2.0) >= 2.24
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libpng)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libgxps is a GObject based library for handling and rendering XPS
documents.

%package -n libgxps2
Summary:        Library for rendering XPS documents
Group:          System/Libraries

%description -n libgxps2
libgxps is a GObject based library for handling and rendering XPS
documents.

%package -n typelib-1_0-GXPS-0_1
Summary:        Library for rendering XPS documents -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GXPS-0_1
libgxps is a GObject based library for handling and rendering XPS
documents.

This package provides the GObject Introspection bindings for libgxps.

%package tools
Summary:        Library for rendering XPS documents -- Tools
Group:          Productivity/Publishing/Other

%description tools
libgxps is a GObject based library for handling and rendering XPS
documents.

%package devel
Summary:        Library for rendering XPS documents -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libgxps2 = %{version}
Requires:       typelib-1_0-GXPS-0_1 = %{version}

%description devel
libgxps is a GObject based library for handling and rendering XPS
documents.

%prep
%setup -q
%patch0 -p1

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%post -n libgxps2 -p /sbin/ldconfig

%postun -n libgxps2 -p /sbin/ldconfig

%files -n libgxps2
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_libdir}/libgxps.so.2*

%files -n typelib-1_0-GXPS-0_1
%defattr(-, root, root)
%{_libdir}/girepository-1.0/GXPS-0.1.typelib

%files tools
%defattr(-, root, root)
%{_bindir}/xpstojpeg
%{_bindir}/xpstopdf
%{_bindir}/xpstopng
%{_bindir}/xpstops
%{_bindir}/xpstosvg

%files devel
%defattr(-, root, root)
%{_includedir}/libgxps/
%{_libdir}/libgxps.so
%{_libdir}/pkgconfig/libgxps.pc
%{_datadir}/gir-1.0/GXPS-0.1.gir
%doc %{_datadir}/gtk-doc/html/libgxps/

%changelog
* Fri Feb 15 2013 pgajdos@suse.com
- Add libgxps-libpng16.patch, also build against libpng16.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 0.2.2:
  + Bug fixes:
  - Fix COPYING file that used lgl2 instead of lgpl2.1
    (bgo#671271)
  - Fix the build with --enable-gtk-doc (bgo#671274)
  - Fix several memory leaks when parsing fails (bgo#668937,
    bgo#668940, bgo#668941, bgo#668969, bgo#668968, bgo#668966,
    bgo#668965)
  + Tools:
  - Set image parameters after jpeg_set_defaults(), so the
    resolution does not get overwritten by the defaults
  + Documentation:
  - Ignore private headers when generating API doc
  - Add index of new symbols in 0.2.1
  - Add Since: tag to GXPS_VERSION_STRING api docs
* Sat Jan 21 2012 vuntz@opensuse.org
- Update to version 0.2.1:
  + API changes:
  - Add GXPS_VERSION_STRING macro with the library version as a
    string
  + New features:
  - Support OpacityMask for Path elements (bgo#663477)
  + Bug fixes:
  - Fix MAJOR/MINOR/MICRO version macros
  - Fix FSF address in COPYING file
  - Fix building with libpng15 (bgo#664666)
  - Fix tools build by linking to libm (bgo#664439)
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop libgxps-link-libm.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  those were only needed for patch above.
* Mon Jan  9 2012 vuntz@opensuse.org
- Split typelib file into typelib-1_0-GXPS-0_1 subpackage.
- Add typelib-1_0-GXPS-0_1 Requires to devel subpackage.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 0.2.0:
  + API changes:
  - This release contains a small API break. Even though all of
    the XPS documents we have for testing use integer numbers for
    the page size, the XPS Specification says that page size is a
    double value. Functions gxps_page_get_size() and
    gxps_document_get_page_size() now return page width and page
    height as gdouble values instead of guint.
  + New features:
  - Add support for PolyQuadraticBezierSegment figures
  - Add support for Smooth Cubic Bézier curve
  - Initial implementation of ICC based colors. Only CMYK colors
    are supported for now
  - Support Opacity for SolidColorBrush elements (bgo#663472)
  - Add support for scRGB color syntax
  - Implement Quadratic Bézier curve
  - Support OpacityMask for Glyphs elements (bgo#66347)
  - Support OpacityMask for Canvas elements (bgo#663475)
  - Support opacity for ImageBrush elements (bgo#663471)
  - Support opacity for Glyphs elements (bgo#662654)
  - Support opacity for Canvas elements (bgo#662653)
  - Support opacity for Path elements (bgo#662652)
  - Support opacity for LinearGradientBrush and
    RadialGradientBrush elements (bgo#662655)
  + Bug fixes:
  - Fix parser error messages for invalid content (bgo#663899)
  + Tools:
  - Add xpstojpeg tool for converting XPS documents to JPEG
  - Add xpstosvg tool for converting XPS documents to SVG
  - Add xpstops tool for converting XPS documents to PostScript
  - Add xpstopdf tool for converting XPS documents to PDF
  - Add xpstopng tool for converting XPS documents to PNG
  + Updated documentation.
- Add libgxps-link-libm.patch: Add missing libm linking.
- Add gnome-common BuildRequires and call to gnome-autogen.sh for
  above patch.
- Add pkgconfig(cairo-pdf), pkgconfig(cairo-ps),
  pkgconfig(cairo-svg), pkgconfig(lcms2) and pkgconfig(libpng)
  BuildRequires: new dependencies upstream.
- Rename libgxps1 subpackage to libgxps2, following upstream
  soversion change.
- Create a tools subpackage to distribute the various new tools.
* Wed Nov 16 2011 vuntz@opensuse.org
- Initial package (0.1.0)
